# START

# Title:  Define globals
# Author: Sebastian Weinand
# Date:   22 July 2024

# see https://community.rstudio.com/t/how-to-solve-no-visible-binding-for-global-variable-note/28887
utils::globalVariables(
  c("is_base",
    "p_base",
    "q_base",
    "w_base",
    "p_qbase",
    "q_qbase",
    "region",
    "group",
    "weight",
    "price",
    "error",
    "prod_share",
    "turnover",
    "prod_turnover",
    "quantity",
    "product",
    "N")
  )

# END
